﻿using MVR.FileManagementSecure;
using SimpleJSON;

namespace noone77521
{
    internal partial class MMDShowcase : MVRScript
    {
        const string storeFile = "Saves\\PluginData\\MMDShowcase\\data.json";
        JSONStorableBool _showIntro;
        JSONStorableBool _catched;
        JSONStorableBool _touchHandLeft;

        const int COOLDOWN_FRAMES = 60;
        int _lockFrames = 0;

        void Update()
        {
            if (_lockFrames > 0)
            {
                _lockFrames--;
            }
        }

        public override void Init()
        {
            _catched = new JSONStorableBool("Catched", false);
            RegisterBool(_catched);

            _touchHandLeft = new JSONStorableBool("LeftHandTouching", true);
            RegisterBool(_touchHandLeft);

            var dir = FileManagerSecure.GetDirectoryName(storeFile);
            FileManagerSecure.CreateDirectory(dir);

            var showIntro = true;
            if (FileManagerSecure.FileExists(storeFile))
            {
                var json = SuperController.singleton.LoadJSON(storeFile);

                if (json != null)
                {
                    var jc = json.AsObject;

                    if (jc.HasKey("show_intro"))
                    {
                        showIntro = jc["show_intro"].AsBool;
                    }
                }
            }

            _showIntro = new JSONStorableBool($"Show Intro", showIntro);
            _showIntro.setCallbackFunction = b =>
            {
                var jco = new JSONClass();
                jco["show_intro"].AsBool = b;

                SuperController.singleton.SaveJSON(jco, storeFile);
            };
            RegisterBool(_showIntro);
            CreateToggle(_showIntro);

            RegisterAction(new JSONStorableAction("HideMonitorUI", () =>
            {
                SuperController.singleton.HideMainHUD();
                SuperController.singleton.HideMonitorUI();
            }));

            RegisterAction(new JSONStorableAction("ShowMonitorUI", () =>
            {
                SuperController.singleton.ShowMonitorUI();
            }));

            RegisterAction(new JSONStorableAction("ResetFOV", () =>
            {
                SuperController.singleton.monitorCameraFOV = SuperController.singleton.startingMonitorCameraFOV;
            }));

            RegisterAction(new JSONStorableAction("ToggleCatchL", ToggleCatchL));
            RegisterAction(new JSONStorableAction("ToggleCatchR", ToggleCatchR));
        }

        /// <summary>
        /// 切换抓取状态
        /// </summary>
        void ToggleCatchL()
        {
            ToggleCatch(true);
        }

        /// <summary>
        /// 切换抓取状态
        /// </summary>
        void ToggleCatchR()
        {
            ToggleCatch(false);
        }

        void ToggleCatch(bool leftHand)
        {
            // 如果锁定帧数没有清零，则不执行
            if (_lockFrames > 0) return;

            _lockFrames = COOLDOWN_FRAMES;

            _touchHandLeft.val = leftHand;

            _catched.val = !_catched.val;
        }
    }
}
